@@ -25,7 +25,7 @@ public:
     QList<BacktraceLine> m_linesToRate;
     QStringList m_firstUsefulFunctions;
     QString m_simplifiedBacktrace;
-    QSet<QString> m_librariesWithMissingDebugSymbols;
+    QStringList m_librariesWithMissingDebugSymbols;
     BacktraceParser::Usefulness m_usefulness;
     bool m_compositorCrashed = false;
 };
